@@ -12,6 +12,8 @@ from writer import SlideTranslator
 
 class AbstractSlideBuilder(object):
 
+    add_permalinks = False
+
     def init_translator_class(self):
         self.translator_class = SlideTranslator
 
@@ -51,9 +53,9 @@ class AbstractSlideBuilder(object):
 
 class DirectorySlideBuilder(AbstractSlideBuilder, DirectoryHTMLBuilder):
 
-    name = 'dirhtml5slides'
+    name = 'dirslides'
 
 
 class SlideBuilder(AbstractSlideBuilder, StandaloneHTMLBuilder):
 
-    name = 'html5slides'
+    name = 'slides'
