@@ -13,9 +13,10 @@
 var PERMANENT_URL_PREFIX = DOCUMENTATION_OPTIONS.URL_ROOT + '_static/';
 
 var SLIDE_CLASSES = ['far-past', 'past', 'current', 'next', 'far-next'];
+var SLIDES_SELECTOR = 'section.slides > article';
 
 var PM_TOUCH_SENSITIVITY = 15;
-
+var TABLE_CLASS = 'table';
 var curSlide;
 
 /* ---------------------------------------------------------------------- */
@@ -227,6 +228,8 @@ function buildNextItem() {
 };
 
 function prevSlide() {
+  if (slidesContainer.classList.contains(TABLE_CLASS)) return;
+
   if (curSlide > 0) {
     curSlide--;
 
@@ -235,6 +238,8 @@ function prevSlide() {
 };
 
 function nextSlide() {
+  if (slidesContainer.classList.contains(TABLE_CLASS)) return;
+
   if (buildNextItem()) {
     return;
   }
@@ -246,6 +251,40 @@ function nextSlide() {
   }
 };
 
+function showSlide(e) {
+
+    if (!slidesContainer.classList.contains(TABLE_CLASS)) return;
+
+    // toggle table class
+    toggleView();
+
+    // set curSlide
+    if (e) {
+        for (i = 0; i < slideEls.length; i++) {
+            if (slideEls[i].contains(e.target)) {
+                curSlide = i;
+                break;
+            }
+        }
+    }
+
+    // update slide classes
+    updateSlides();
+};
+
+function toggleView() {
+  for (var i = 0; i < slideEls.length; i++) {
+      updateSlideClass(i);
+  };
+
+  if (slidesContainer.classList.contains(TABLE_CLASS)) {
+      // leaving table mode
+      updateSlides();
+  }
+
+  slidesContainer.classList.toggle(TABLE_CLASS);
+};
+
 /* Slide events */
 
 function triggerEnterEvent(no) {
@@ -396,6 +435,12 @@ function setupInteraction() {
   /* Swiping */
 
   document.body.addEventListener('touchstart', handleTouchStart, false);
+
+  /* Clicking Slides */
+  for (i = 0; i < slideEls.length; i++) {
+      slideEls[i].addEventListener('click', showSlide, false);
+  }
+
 }
 
 /* ChromeVox support */
@@ -466,8 +511,39 @@ function speakPrevItem() {
 
 /* Hash functions */
 
+function findSlideById(title_id) {
+    // Return the 1-base index of the Slide with id ``title_id``
+    //
+    // The index must be 1-based, as it's passed to code which assumes
+    // it was specified as the location fragment.
+
+    for (var i = 0; i < slideEls.length; i++) {
+        if (slideEls.item(i).id == title_id) {
+            return i + 1;
+        }
+    }
+
+    // no match on a slide, perhaps it's an explicit reference?
+    var
+    target_link = document.querySelector("span[id='" + title_id + "']"),
+    // XXX this is pretty strict, may need to be more flexible in the future
+    slide = (target_link && target_link.parentNode);
+
+    if (slide && slide.tagName == 'ARTICLE') {
+        return findSlideById(slide.id);
+    }
+
+    return false;
+
+};
+
 function getCurSlideFromHash() {
-  var slideNo = parseInt(location.hash.substr(1));
+  var slideNo = Number(location.hash.substr(1));
+
+  if (isNaN(slideNo)) {
+      // must be a section title reference
+      slideNo = findSlideById(location.hash.substr(1));
+  }
 
   if (slideNo) {
     curSlide = slideNo - 1;
@@ -516,6 +592,11 @@ function handleBodyKeyDown(event) {
       }
       event.preventDefault();
       break;
+
+    case 27: // ESC
+      toggleView();
+      break;
+
   }
 };
 
@@ -582,8 +663,10 @@ function makeBuildLists() {
 };
 
 function handleDomLoaded() {
-  slideEls = document.querySelectorAll('section.slides > article');
+  slidesContainer = document.querySelector('section.slides');
+  slideEls = document.querySelectorAll(SLIDES_SELECTOR);
 
+  getCurSlideFromHash();
   setupFrames();
 
   addFontStyle();
@@ -600,8 +683,6 @@ function handleDomLoaded() {
 };
 
 function initialize() {
-  getCurSlideFromHash();
-
   if (window['_DEBUG']) {
     PERMANENT_URL_PREFIX = '../';
   }
